.. :changelog:

History
=======

0.3.0 - 2016-09-23
------------------

* Set up table scraping parameters and execution
* Fix json configuration generation

0.2.6 - 2015-11-27
------------------

* Edit requirements

0.2.5 - 2015-05-28
------------------

* Add levels argument for genconfig command, to create crawler config files for a specific depth

0.2.4 - 2015-04-13
------------------

* Update documentation
* Minor fixes

0.2.3 - 2015-03-11
------------------

* Include implementation to use csv as the output format

0.2.2 - 2015-02-22
------------------

* Fix bug in generate script template

0.2.1 - 2015-02-21
------------------

* Update tests

0.2.0 - 2015-02-20
------------------

* Include implementation for ``scrapple run`` and ``scrapple generate`` for crawlers
* Modify web interface for editing scraper config files
* Revise skeleton configuration files

0.1.1 - 2015-02-10
------------------

* Release on PyPI with revisions
* Include web interface for editing scraper config files
* Modified implementations of certain functions

0.1.0 - 2015-02-04
------------------

* First release on PyPI
